﻿using NPOI.HSSF.UserModel;
using NPOI.SS.UserModel;
using NPOI.XSSF.UserModel;
using Performance.DtoModels;
using Performance.EntityModels;
using Performance.Infrastructure;
using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;

namespace Performance.Services
{
    public class PerExcelService : IAutoInjection
    {
        private PerSheetService _perSheetService;
        public PerExcelService(PerSheetService perSheetService)
        {
            _perSheetService = perSheetService;
        }
        
        /// <summary>
        /// 导入excel数据
        /// </summary>
        /// <param name="path"></param>
        /// <returns></returns>
        public PerExcel Import(string path)
        {
            PerExcel excel = new PerExcel
            {
                Path = path,
                FileName = FileHelper.GetFileNameNoExtension(path),
                Version = FileHelper.GetExtension(path) == ".xlsx" ? ExcelVersion.xlsx : ExcelVersion.xls,
                PerSheet = new List<PerSheet>()
            };
            using (FileStream fs = new FileStream(path, FileMode.Open))
            {
                IWorkbook workbook = (excel.Version == ExcelVersion.xlsx)
                    ? (IWorkbook)(new XSSFWorkbook(fs))
                    : (IWorkbook)(new HSSFWorkbook(fs));
                for (int i = 0; i < workbook.NumberOfSheets; i++)
                {
                    var sheet = workbook.GetSheetAt(i);
                    if (SheetType.Unidentifiable != _perSheetService.GetSheetType(sheet.SheetName))
                    {
                        var st = _perSheetService.Sheet(sheet);
                        excel.PerSheet.Add(st);
                    }
                }
                return excel;
            }
        }

        private List<im_employee> C(List<PerData> dataList)
        {
            List<im_employee> result = new List<im_employee>();
            var empList = dataList.GroupBy(t => new { t.AccountingUnit, t.Department })
                .Select(t => new { t.Key, Employee = t.Select(p => (PerDataEmployee)p) });
            foreach (var gkey in empList)
            {
                im_employee employee = new im_employee
                {
                    AccountingUnit = gkey.Key.AccountingUnit,
                    Department = gkey.Key.Department,
                    DoctorName = gkey.Employee.FirstOrDefault(t => t.TypeName == "医生姓名").CellValue,
                    FitPeople = ConvertHelper.To<decimal?>(gkey.Employee.FirstOrDefault(t => t.TypeName == "绩效基数核算参考对象")?.CellValue),
                    JobTitle = gkey.Employee.FirstOrDefault(t => t.TypeName == "职称")?.CellValue,
                    PostCoefficient = ConvertHelper.To<decimal?>(gkey.Employee.FirstOrDefault(t => t.TypeName == "岗位系数")?.CellValue),
                    WorkTime = ConvertHelper.To<DateTime?>(gkey.Employee.FirstOrDefault(t => t.TypeName == "考核得分率")?.CellValue),
                    ScoreAverageRate = ConvertHelper.To<decimal?>(gkey.Employee.FirstOrDefault(t => t.TypeName == "医生姓名")?.CellValue),
                    Attendance = ConvertHelper.To<decimal?>(gkey.Employee.FirstOrDefault(t => t.TypeName == "出勤率")?.CellValue),
                    PeopleNumber = ConvertHelper.To<int?>(gkey.Employee.FirstOrDefault(t => t.TypeName == "核算单元医生数")?.CellValue),
                    Workload = ConvertHelper.To<decimal?>(gkey.Employee.FirstOrDefault(t => t.TypeName == "工作量绩效")?.CellValue),
                    OthePerfor = ConvertHelper.To<decimal?>(gkey.Employee.FirstOrDefault(t => t.TypeName == "其他绩效")?.CellValue),
                    Punishment = ConvertHelper.To<decimal?>(gkey.Employee.FirstOrDefault(t => t.TypeName == "医院奖罚")?.CellValue),
                    Adjust = ConvertHelper.To<decimal?>(gkey.Employee.FirstOrDefault(t => t.TypeName == "调节系数")?.CellValue),
                    Grant = ConvertHelper.To<decimal?>(gkey.Employee.FirstOrDefault(t => t.TypeName == "发放系数")?.CellValue)
                };
                result.Add(employee);
            }

            return result;
        }

        public void Copy(int iD)
        {
            throw new NotImplementedException();
        }

        public void ImportSave(PerExcel excel)
        {
            throw new NotImplementedException();
        }

        public void ProcessCompute(PerExcel excel)
        {
            throw new NotImplementedException();
        }

        public void ProcessSave(PerExcel excel)
        {
            throw new NotImplementedException();
        }

        public void Compute(PerExcel excel)
        {
            throw new NotImplementedException();
        }
    }
}
