﻿using NPOI.SS.UserModel;
using Performance.DtoModels;
using Performance.Infrastructure;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace Performance.Services
{
    public class PerSheetService : IAutoInjection
    {
        PerHeaderService _perHeader;
        public PerSheetService(PerHeaderService perHeader)
        {
            _perHeader = perHeader;
        }

        /// <summary>
        /// 解析excel数据
        /// </summary>
        /// <param name="sheet"></param>
        /// <returns></returns>
        public PerSheet Sheet(ISheet sheet)
        {
            PerSheet perSheet = new PerSheet();
            perSheet.SheetName = sheet.SheetName;
            perSheet.SheetType = GetSheetType(sheet.SheetName);
            perSheet.ModuleName = EnumHelper.GetDescription(perSheet.SheetType);

            if (perSheet.SheetType == SheetType.Unidentifiable)
                return null;

            var sheetRead = PerSheetDataFactory.GetDataRead(perSheet.SheetType);
            perSheet.PerHeader = _perHeader.GetPerHeaderReverse(sheet, sheetRead.Point);
            perSheet.PerData = sheetRead.ReadData(sheet, perSheet.PerHeader);
            return perSheet;
        }

        public SheetType GetSheetType(string sheetName)
        {
            if (sheetName.StartsWith("医院人员名单"))
                return SheetType.Employee;
            else if (sheetName.StartsWith("1.0"))
                return SheetType.OtherIncome;
            else if (sheetName.StartsWith("1."))
                return SheetType.Income;
            else if (sheetName.StartsWith("2."))
                return SheetType.Expend;
            else if (sheetName.StartsWith("3."))
                return SheetType.Workload;
            return SheetType.Unidentifiable;
        }

        //public List<PerData> AnalyzeData(ISheet sheet, IPerSheetDataRead sheetRead, List<PerHeader> headList)
        //{
        //    List<PerData> dataList = new List<PerData>();

        //    foreach (var unit in sheetRead.Point.AccountingUnit)
        //    {
        //        var vhead = headList.Where(t => t.PointCell != unit.AccountingUnitCellNum && t.PointCell != unit.DeptCellNum).OrderBy(t => t.PointCell);

        //        for (int r = sheetRead.Point.DataFirstRowNum.Value; r < sheet.LastRowNum + 1; r++)
        //        {
        //            var row = sheet.GetRow(r);
        //            for (int c = 0; c < vhead.Count(); c++)
        //            {
        //                PerData data = sheetRead.GetPerData(row, vhead.ElementAt(c));
        //                dataList.Add(data);
        //            }
        //        }
        //    }
        //    return dataList;
        //}
    }
}
