﻿using NPOI.SS.UserModel;
using Performance.DtoModels;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace Performance.Services
{
    /// <summary>
    /// 人员读取
    /// </summary>
    public class PerSheetDataReadEmployee : IPerSheetDataRead
    {
        public PerSheetPoint Point => new PerSheetPoint
        {
            HeaderFirstRowNum = 0,
            HeaderLastRowNum = 0,
            HeaderFirstCellNum = 0,
            DataFirstRowNum = 1,
            AccountingUnit = new List<AccountingUnit>
            {
               new AccountingUnit
               {
                    AccountingUnitCellNum = 0,
                    DeptCellNum = 1
               }
            }
        };


        public List<PerData> ReadData(ISheet sheet, List<PerHeader> perHeader)
        {
            List<PerData> dataList = new List<PerData>();

            foreach (var unit in Point.AccountingUnit)
            {
                var vhead = perHeader.Where(t => t.PointCell != unit.AccountingUnitCellNum && t.PointCell != unit.DeptCellNum).OrderBy(t => t.PointCell);

                for (int r = Point.DataFirstRowNum.Value; r < sheet.LastRowNum + 1; r++)
                {
                    var row = sheet.GetRow(r);
                    for (int c = 0; c < vhead.Count(); c++)
                    {
                        //PerData data = sheetRead.GetPerData(row, vhead.ElementAt(c));
                        PerData data = new PerDataEmployee
                        {
                            AccountingUnit = row.GetCell(unit.AccountingUnitCellNum.Value)?.ToString(),
                            Department = row.GetCell(unit.DeptCellNum.Value)?.ToString(),
                            TypeName = vhead.ElementAt(c)?.CellName,
                            CellValue = row.GetCell(vhead.ElementAt(c).PointCell)?.ToString(),
                            Annotation = row.GetCell(vhead.ElementAt(c).PointCell)?.CellComment?.String?.String,
                        };
                        dataList.Add(data);
                    }
                }
            }
            return dataList;
        }
    }
}
