﻿using NPOI.SS.UserModel;
using Performance.DtoModels;
using Performance.Infrastructure;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace Performance.Services
{
    public class PerSheetDataReadOtherIncome : IPerSheetDataRead
    {
        public PerSheetPoint Point => new PerSheetPoint
        {
            HeaderFirstRowNum = 1,
            HeaderLastRowNum = 1,
            HeaderFirstCellNum = 0,
            DataFirstRowNum = 2,
            AccountingUnit = new List<AccountingUnit>
            {
                new AccountingUnit
                {
                    AccountingUnitCellNum = 0,
                    DeptCellNum = 1
                }
            }
        };

        public List<PerData> ReadData(ISheet sheet, List<PerHeader> perHeader)
        {
            List<PerData> dataList = new List<PerData>();

            foreach (var unit in Point.AccountingUnit)
            {
                var vhead = perHeader.Where(t => t.PointCell != unit.AccountingUnitCellNum && t.PointCell != unit.DeptCellNum).OrderBy(t => t.PointCell);

                for (int r = Point.DataFirstRowNum.Value; r < sheet.LastRowNum + 1; r++)
                {
                    var row = sheet.GetRow(r);
                    for (int c = 0; c < vhead.Count(); c++)
                    {
                        var accountingUnit = row.GetCell(unit.AccountingUnitCellNum.Value)?.ToString();
                        if (string.IsNullOrEmpty(accountingUnit))
                            continue;
                        var athead = vhead.ElementAt(c);
                        PerData data = new PerDataOtherIncome
                        {
                            AccountingUnit = accountingUnit,
                            Department = row.GetCell(unit.DeptCellNum.Value)?.ToString(),
                            TypeName = athead?.CellName,
                            CellValue = ConvertHelper.To<decimal?>(row.GetCell(athead.PointCell)?.ToString()),
                            Annotation = row.GetCell(athead.PointCell)?.CellComment?.String?.String,
                        };
                        if (sheet.SheetName.Contains("医生组"))
                        {
                            data.UnitType = "医生组";
                        }
                        else if (sheet.SheetName.Contains("护理组"))
                        {
                            data.UnitType = "护理组";
                        }
                        else if (perHeader.Any(t => t.CellName.Contains("核算单元") && t.CellName.Contains("医生组")))
                        {
                            data.UnitType = "医生组";
                        }
                        else if (perHeader.Any(t => t.CellName.Contains("核算单元") && t.CellName.Contains("护理组")))
                        {
                            data.UnitType = "护理组";
                        }

                        dataList.Add(data);
                    }
                }
            }
            return dataList;
        }
    }
}
