﻿using NPOI.SS.UserModel;
using Performance.DtoModels;
using Performance.Infrastructure;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace Performance.Services
{
    /// <summary>
    /// 工作量
    /// </summary>
    public class PerSheetDataReadWorkload : IPerSheetDataRead
    {
        public PerSheetPoint Point => new PerSheetPoint
        {
            HeaderFirstRowNum = 1,
            HeaderLastRowNum = 2,
            HeaderFirstCellNum = 1,
            DataFirstRowNum = 4,
            AccountingUnit = new List<AccountingUnit>
            {
               new AccountingUnit
               {
                    AccountingUnitCellNum = 0,
                    DeptCellNum = 1,
                    FactorRow = 3
               }
            }
        };

        public List<PerData> ReadData(ISheet sheet, List<PerHeader> perHeader)
        {
            List<PerData> dataList = new List<PerData>();

            //循环 当前有几个核算单元
            foreach (var unit in Point.AccountingUnit)
            {
                var vhead = perHeader.Where(t => !Point.AccountingUnit.Select(p => p.AccountingUnitCellNum).Contains(t.PointCell)
                    && !Point.AccountingUnit.Select(p => p.DeptCellNum).Contains(t.PointCell)).OrderBy(t => t.PointCell);
                for (int r = Point.DataFirstRowNum.Value; r < sheet.LastRowNum + 1; r++)
                {
                    var row = sheet.GetRow(r);
                    for (int c = 0; c < vhead.Count(); c++)
                    {
                        var accountingUnit = row.GetCell(unit.AccountingUnitCellNum.Value)?.ToString();
                        if (string.IsNullOrEmpty(accountingUnit))
                            continue;
                        var athead = vhead.ElementAt(c);
                        //PerData data = sheetRead.GetPerData(row, vhead.ElementAt(c));
                        PerData data = new PerDataWorkload
                        {
                            AccountingUnit = accountingUnit,
                            Department = row.GetCell(unit.DeptCellNum.Value)?.ToString(),
                            TypeName = athead?.CellName,
                            CellValue = ConvertHelper.To<decimal?>(row.GetCell(athead.PointCell)?.ToString()),
                            Annotation = row.GetCell(athead.PointCell)?.CellComment?.String?.String,
                            UnitType = unit.UnitType,
                            FactorValue = ConvertHelper.To<decimal?>(sheet.GetRow(unit.FactorRow.Value).GetCell(athead.PointCell)?.ToString()),
                        };
                        if (sheet.SheetName.Contains("医生组"))
                        {
                            data.UnitType = "医生组";
                        }
                        else if (sheet.SheetName.Contains("护理组"))
                        {
                            data.UnitType = "护理组";
                        }
                        dataList.Add(data);
                    }
                }
            }
            return dataList;
        }
    }
}
